Saxophone Repair Kit - $18.99 : Instrument Clinic, Band Instrument Repair Supplies
Author: The Zen Cart™ Team and others
Description: Instrument Clinic Saxophone Repair Kit - Kit includes the following:(5) Instrument Clinic IC640 Saxphone Pads, Made in USA!(1) Seamless Natural Neck Cork(4) Stainless Steel Sax Springs(1) Small Tube of Instrument Clinic Pad Adhesive Crystals(1) Tube of Shellac Flakes for Neck Cork Installation(1) .15oz Tube of Cork Grease, Made in USA!(1) Piece of Sandpaper(1) Instrument Clinic Clarinet
Keywords: Saxophone Repair Kit Woodwind Pads Band Instrument Repair Tools Band Instrument Repair Supplies Cork Supplies Woodwind Springs Clarinet Cork Kits Saxophone Neck Cork Kits Flute Head Cork Cork Grease Flute Pad Kits Saxophone Pad Kits Clarinet Pad Kits Woodwind Repair Kits Maintenance Products Woodwind Accessories ecommerce, open source, shop, online shopping

- Home
- Log In

### Products Band Instrument Repair Supplies Band Instrument Repair Tools Clarinet Cork Kits Clarinet Pad Kits Cork Grease Cork Supplies Flute Head Cork Flute Pad Kits Maintenance Products Saxophone Neck Cork Kits Saxophone Pad Kits Woodwind Accessories Woodwind Pads Woodwind Repair Kits Clarinet Repair Kit Flute Repair Kit Saxophone Repair Kit Woodwind Springs All Products ... ### Education Center How to Measure Flute Pads How to Measure Clarinet Pads How to Measure Clarinet Springs How to Measure Flute Springs How to Measure Saxophone Pads How to Replace Clarinet Cork How to Replace Flute Pads How to Replace Saxophone Pads How to Replace Clarinet Pads How to Replace Flute Head Cork How to Replace Sax Neck Cork ### Information Contact Us Payment Information Shipping & Returns Privacy Notice Conditions of Use Discount Coupons Newsletter Unsubscribe Copyright Notice Site Map ### Search Advanced Search | Home :: Woodwind Repair Kits :: Saxophone Repair Kit :: Saxophone Repair Kit Saxophone Repair Kit # Saxophone Repair Kit ## $18.99 Kit includes the following: (5) Instrument Clinic IC640 Saxphone Pads, Made in USA! (1) Seamless Natural Neck Cork (4) Stainless Steel Sax Springs (1) Small Tube of Instrument Clinic Pad Adhesive Crystals (1) Tube of Shellac Flakes for Neck Cork Installation (1) .15oz Tube of Cork Grease, Made in USA! (1) Piece of Sandpaper (1) Instrument Clinic Clarinet Repair Screwdriver Add to Cart: |

- Home

Your IP Address is: 5.165.17.247
Copyright © 2014 Instrument Clinic USA. Powered by Zen Cart